%% This main file is used to execute the simulation functions for the nonlinear vibrations of thin plates. 

%% Input parameters files
PlateCharacteristicsFileName = 'PlateCharacteristics-CaseR5.mat'; % Physical characteristics of the plate: Dimensions, imperfection profile, material and boundary conditions.  
SimulationParametersFileName = 'SimulationParameters-CaseR5.mat'; % Parameters related to the simulation: Time length, scheme, number of modes, output points, accuracy.
GammaFileName = 'GammaRectangular-CaseR5.mat'; % Name of the file containing the Gamma Tensor.  
ScoreFileName = 'ScoreParameters-CaseR5.mat'; % Characteristics of the excitation. 
OutputFileName = 'ResultsCaseR5'; % Name of the results files and folder. 

%% Simulation setup 
[Lx, Ly, hd, E, rho, BC, e, Nphi, Npsi, scheme, H0, H1, H2, filename, Ai, C, C1, C2, kx, ky, om_dim, rp, tad, fsd, Tsd] = plate_def_rect(PlateCharacteristicsFileName, SimulationParametersFileName, OutputFileName, GammaFileName );

[ f_time, Tn ] = score_rect( ScoreFileName, Lx, Ly, hd, rho, kx, ky, BC, Nphi, scheme, C, fsd, Tsd);

%% Time simulation
switch scheme
    case 'ECS'
        [out_nd] = ftime_imperfect_ECS( Nphi, Npsi, Ai, H0, H1, H2, C, C1,C2, Tn, e, f_time, rp);
        
    case 'verlet'
        [out_nd] = ftime_imperfect_verlet( Nphi, Npsi, Ai, H1, C, C1, C2, Tn, e, f_time, rp);
    
    otherwise
        disp('Unknown scheme');
end


out = out_nd*hd; % Dimensioned output displacement
out_vel = diff(out,1,1)*fsd; % Dimensioned output velocity

for i = 1:size(rp,1)
    audiowrite(sprintf('%s-Op_%d.wav',filename, i),out_vel(:,i)/1.1/max(abs(out_vel(:,i))),fsd);
end
save(sprintf('%s.mat',filename), 'out', 'out_vel',  'fsd');